==> huaweicloudsdkga-3.1.98-py2.py3-none-any.whl: huaweicloudsdkga/v1/model/list_resources_by_tag_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListResourcesByTagRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'tags': 'list[Tag]',
        'matches': 'list[Match]'
    }

    attribute_map = {
        'tags': 'tags',
        'matches': 'matches'
    }

    def __init__(self, tags=None, matches=None):
        """ListResourcesByTagRequestBody

        The model defined in huaweicloud sdk

        :param tags: 标签列表。
        :type tags: list[:class:`huaweicloudsdkga.v1.Tag`]
        :param matches: 匹配项列表。
        :type matches: list[:class:`huaweicloudsdkga.v1.Match`]
        """
        
        

        self._tags = None
        self._matches = None
        self.discriminator = None

        if tags is not None:
            self.tags = tags
        if matches is not None:
            self.matches = matches

    @property
    def tags(self):
        """Gets the tags of this ListResourcesByTagRequestBody.

        标签列表。

        :return: The tags of this ListResourcesByTagRequestBody.
        :rtype: list[:class:`huaweicloudsdkga.v1.Tag`]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this ListResourcesByTagRequestBody.

        标签列表。

        :param tags: The tags of this ListResourcesByTagRequestBody.
        :type tags: list[:class:`huaweicloudsdkga.v1.Tag`]
        """
        self._tags = tags

    @property
    def matches(self):
        """Gets the matches of this ListResourcesByTagRequestBody.

        匹配项列表。

        :return: The matches of this ListResourcesByTagRequestBody.
        :rtype: list[:class:`huaweicloudsdkga.v1.Match`]
        """
        return self._matches

    @matches.setter
    def matches(self, matches):
        """Sets the matches of this ListResourcesByTagRequestBody.

        匹配项列表。

        :param matches: The matches of this ListResourcesByTagRequestBody.
        :type matches: list[:class:`huaweicloudsdkga.v1.Match`]
        """
        self._matches = matches

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListResourcesByTagRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkga-3.1.149-py2.py3-none-any.whl: huaweicloudsdkga/v1/model/list_resources_by_tag_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListResourcesByTagRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'tags': 'list[Tag]',
        'matches': 'list[Match]'
    }

    attribute_map = {
        'tags': 'tags',
        'matches': 'matches'
    }

    def __init__(self, tags=None, matches=None):
        r"""ListResourcesByTagRequestBody

        The model defined in huaweicloud sdk

        :param tags: 标签列表。
        :type tags: list[:class:`huaweicloudsdkga.v1.Tag`]
        :param matches: 匹配项列表。
        :type matches: list[:class:`huaweicloudsdkga.v1.Match`]
        """
        
        

        self._tags = None
        self._matches = None
        self.discriminator = None

        if tags is not None:
            self.tags = tags
        if matches is not None:
            self.matches = matches

    @property
    def tags(self):
        r"""Gets the tags of this ListResourcesByTagRequestBody.

        标签列表。

        :return: The tags of this ListResourcesByTagRequestBody.
        :rtype: list[:class:`huaweicloudsdkga.v1.Tag`]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        r"""Sets the tags of this ListResourcesByTagRequestBody.

        标签列表。

        :param tags: The tags of this ListResourcesByTagRequestBody.
        :type tags: list[:class:`huaweicloudsdkga.v1.Tag`]
        """
        self._tags = tags

    @property
    def matches(self):
        r"""Gets the matches of this ListResourcesByTagRequestBody.

        匹配项列表。

        :return: The matches of this ListResourcesByTagRequestBody.
        :rtype: list[:class:`huaweicloudsdkga.v1.Match`]
        """
        return self._matches

    @matches.setter
    def matches(self, matches):
        r"""Sets the matches of this ListResourcesByTagRequestBody.

        匹配项列表。

        :param matches: The matches of this ListResourcesByTagRequestBody.
        :type matches: list[:class:`huaweicloudsdkga.v1.Match`]
        """
        self._matches = matches

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListResourcesByTagRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
